@@ -7,8 +7,8 @@
 ### Specific implementations are in seperate files (e.g.: Gaussian, power law).
 ###
 ### Copyright (C) 2009-2015,2017 Sebastian Meyer
-### $Revision: 1864 $
-### $Date: 2017-05-31 17:32:24 +0200 (Wed, 31. May 2017) $
+### $Revision: 2601 $
+### $Date: 2021-01-12 18:04:57 +0100 (Tue, 12. Jan 2021) $
 ################################################################################
 
 
@@ -89,12 +89,10 @@ siaf.constant <- function ()
                           quote(rep.int(1, length(s)/2))),
         ##<- nrow() would take extra time in standardGeneric()
                         envir = .GlobalEnv),
-        ## integration over polydomains is handled specially in twinstim
+        ## integration over polydomains (F) is handled specially in twinstim
         Fcircle = as.function(c(alist(r=, pars=NULL, type=NULL),
                                 quote(pi*r^2)),
                               envir = .GlobalEnv),
-        ## simulation will be handled specially in simEpidataCS, this is only
-        ## included here for completeness
         simulate = as.function(c(alist(n=, pars=NULL, type=NULL, ub=),
                                  quote(runifdisc(n, ub))),
                                envir = getNamespace("surveillance")),
@@ -114,9 +112,11 @@ siaf.constant <- function ()
 siaf.fallback.F <- function (polydomain, f, pars, type, method = "SV", ...)
 {
     if (identical(method,"SV")) {
-        polyCub.SV(polydomain, f, pars, type, alpha=0, ...) # since max at origin
+        polyCub.SV(polyregion = polydomain, f = f, pars, type,
+                   alpha = 0, ...) # since max at origin
     } else {
-        polyCub(polydomain, f, method, pars, type, ...)
+        polyCub(polyregion = polydomain, f = f, method = method,
+                pars, type, ...)
     }
 }
 
@@ -139,8 +139,10 @@ siaf.fallback.Deriv <- function (polydomain, deriv, pars, type,
     deriv1 <- function (s, paridx)
         deriv(s, pars, type)[,paridx,drop=TRUE]
     intderiv1 <- function (paridx)
-        polyCub(polydomain, deriv1, method, paridx=paridx, ...)
-    sapply(seq_along(pars), intderiv1)
+        polyCub(polyregion = polydomain, f = deriv1, method = method,
+                paridx = paridx, ...)
+    vapply(X = seq_along(pars), FUN = intderiv1,
+           FUN.VALUE = 0, USE.NAMES = FALSE)
 }
 
 
@@ -264,12 +266,10 @@ checksiaf <- function (siaf, pargrid, type = 1, tolerance = 1e-5,
 
 checksiaf.F <- function (F, f, pargrid, type=1, method="SV", ...)
 {
-    letterR <- "cheating on codetools::checkUsage"
-    data("letterR", package="spatstat", envir=environment())
-    poly <- shift.owin(letterR, -c(3,2))
     res <- t(apply(pargrid, 1, function (pars) {
-        given <- F(poly, f, pars, type)
-        num <- siaf.fallback.F(poly, f, pars, type, method=method, ...)
+        given <- F(LETTERR, f, pars, type)
+        num <- siaf.fallback.F(polydomain = LETTERR, f = f, pars = pars,
+                               type = type, method = method, ...)
         c(given, num)
     }))
     colnames(res) <- c("F", method)
@@ -282,9 +282,10 @@ checksiaf.Fcircle <- function (Fcircle, f, pargrid, type=1,
     pargrid <- pargrid[rep(1:nrow(pargrid), each=length(rs)),,drop=FALSE]
     rpargrid <- cbind(rs, pargrid, deparse.level=0)
     res <- t(apply(rpargrid, 1, function (x) {
-        c(ana = Fcircle(x[1], x[-1], type),
-          num = siaf.fallback.F(discpoly(c(0,0), x[1], npoly=128, class="owin"),
-                                f, x[-1], type, method=method, ...))
+        disc <- discpoly(c(0,0), x[1L], npoly = 128, class = "owin")
+        c(ana = Fcircle(x[1L], x[-1L], type),
+          num = siaf.fallback.F(polydomain = disc, f = f, pars = x[-1L],
+                                type = type, method = method, ...))
     }))
     res
 }
@@ -303,12 +304,10 @@ checksiaf.deriv <- function (deriv, f, pargrid, type=1, rmax=100)
 
 checksiaf.Deriv <- function (Deriv, deriv, pargrid, type=1, method="SV", ...)
 {
-    letterR <- "cheating on codetools::checkUsage"
-    data("letterR", package="spatstat", envir=environment())
-    poly <- shift.owin(letterR, -c(3,2))
     res <- t(apply(pargrid, 1, function (pars) {
-        given <- Deriv(poly, deriv, pars, type)
-        num <- siaf.fallback.Deriv(poly, deriv, pars, type, method=method, ...)
+        given <- Deriv(LETTERR, deriv, pars, type)
+        num <- siaf.fallback.Deriv(polydomain = LETTERR, deriv = deriv, pars = pars,
+                                   type = type, method = method, ...)
         c(given, num)
     }))
     paridxs <- seq_len(ncol(pargrid))
